==> pmudmon-0.2.tar.gz: pmudmon-0.2/properties.c <==
/* pmudmon applet
 ** Copyright (C) 2000 Mike Palczewski mpalczew@u.washington.edu
 ** 
 ** This program is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License
 ** as published by the Free Software Foundation; either version 2
 ** of the License, or (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 ** 
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 ** 02111-1307, USA.
 **/
#include "main.h"
#include "properties.h"
#include "conf.h"

GtkWidget* width;
GtkWidget* height;
GtkWidget* interval;

GtkProgressBarOrientation menustatus=0;


void menu1 (GtkMenuItem *menuitem,gpointer user_data);
void menu2 (GtkMenuItem *menuitem,gpointer user_data);
void menu3 (GtkMenuItem *menuitem,gpointer user_data);
void menu4 (GtkMenuItem *menuitem,gpointer user_data);


void properties_dialog_clicked(GnomeDialog *dlg, int button, gpointer data);

void doproperties (AppletWidget* l, gpointer m){
	GtkWidget *dialog;
	GtkWidget *label;
	GtkWidget *label2;
	GtkWidget *label3;
	GtkWidget *table;
	GtkWidget *menu;
	GtkWidget *optionmenu;
	GtkWidget *menuitem;
	GtkWidget *label4;
	GtkObject *adjustment;
	GtkObject *adjustment2;
	GtkObject *adjustment3;
	conf* config;

	config=get_conf();
	menustatus=config->orientation;
	
	dialog=gnome_dialog_new("Properties",
			GNOME_STOCK_BUTTON_OK,
			GNOME_STOCK_BUTTON_APPLY,
                        GNOME_STOCK_BUTTON_CLOSE,
                        NULL);

	gtk_signal_connect(GTK_OBJECT(dialog),"clicked",
			GTK_SIGNAL_FUNC(properties_dialog_clicked),
                        NULL);
	

	adjustment=gtk_adjustment_new(config->width,10,700,1,10,10);
	adjustment2=gtk_adjustment_new(config->height,10,700,1,10,10);
	adjustment3=gtk_adjustment_new(config->time,1,1200,1,10,10);
	
	table=gtk_table_new(2,4,FALSE);
	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox),table,
	                FALSE,FALSE,0);
	
	menu=gtk_menu_new();
	menuitem=gtk_menu_item_new_with_label("Left to Right");
	gtk_widget_show(menuitem);
	gtk_menu_append(GTK_MENU(menu),menuitem);
	gtk_signal_connect(GTK_OBJECT(menuitem),"activate",GTK_SIGNAL_FUNC(menu1),NULL);
	
	menuitem=gtk_menu_item_new_with_label("Right to Left");
	gtk_widget_show(menuitem);
        gtk_menu_append(GTK_MENU(menu),menuitem);
        gtk_signal_connect(GTK_OBJECT(menuitem),"activate",GTK_SIGNAL_FUNC(menu2),NULL);
	menuitem=gtk_menu_item_new_with_label("Bottom to Top");
	gtk_widget_show(menuitem);
        gtk_menu_append(GTK_MENU(menu),menuitem);
        gtk_signal_connect(GTK_OBJECT(menuitem),"activate",GTK_SIGNAL_FUNC(menu3),NULL);
	
	menuitem=gtk_menu_item_new_with_label("Top to Bottom");
	gtk_widget_show(menuitem);
        gtk_menu_append(GTK_MENU(menu),menuitem);
        gtk_signal_connect(GTK_OBJECT(menuitem),"activate",GTK_SIGNAL_FUNC(menu4),NULL);
	
	optionmenu=gtk_option_menu_new();
	gtk_option_menu_set_menu(GTK_OPTION_MENU(optionmenu),menu);

	gtk_option_menu_set_history(GTK_OPTION_MENU(optionmenu),
			config->orientation);
	gtk_table_attach_defaults(GTK_TABLE(table),optionmenu,1,2,3,4);	


	
	width=gtk_spin_button_new(GTK_ADJUSTMENT(adjustment),1,0);
	gtk_table_attach_defaults(GTK_TABLE(table),width,1,2,0,1);
	
	height=gtk_spin_button_new(GTK_ADJUSTMENT(adjustment2),1,0);
	gtk_table_attach_defaults(GTK_TABLE(table),height,1,2,1,2);
	
	interval=gtk_spin_button_new(GTK_ADJUSTMENT(adjustment3),1,0);
	gtk_table_attach_defaults(GTK_TABLE(table),interval,1,2,2,3);
	
	gtk_table_attach_defaults(GTK_TABLE(table),
			label=gtk_label_new("Applet Width"),
			0,1,0,1);
	gtk_table_attach_defaults(GTK_TABLE(table),
			label2=gtk_label_new("Applet Height"),
			0,1,1,2);
	gtk_table_attach_defaults(GTK_TABLE(table),
			label4=gtk_label_new("Interval"),
			0,1,2,3);
	gtk_table_attach_defaults(GTK_TABLE(table),
			label3=gtk_label_new("Orientation"),
			0,1,3,4);
	gtk_widget_show(interval);
	gtk_widget_show(label4);
	gtk_widget_show(menu);
	gtk_widget_show(optionmenu);
	gtk_widget_show(label3);	
	gtk_widget_show(label2);
	gtk_widget_show(label);
 	gtk_widget_show(table);	
	gtk_widget_show(height);
	gtk_widget_show(width);	
	gtk_widget_show(dialog);
	free_conf(config);

}


void properties_dialog_clicked(GnomeDialog *dlg, int button, gpointer data){
	GtkRequisition req;
	conf config;
	
	if (button == 0 || button == 1) {
		gtk_widget_set_usize(progress,
			gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(width)),
			gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(height)));
		gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(progress),menustatus);
		config.width=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(width));
		config.height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(height));
		config.time=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(interval));
		gtk_timeout_remove(timeout);
		timeout=gtk_timeout_add(config.time*1000,pmudmain,NULL);
		config.orientation=menustatus;
		config.format_charged=NULL;
		config.format_charging=NULL;
		config.format_battery=NULL;
		set_conf(&config);
		
	}
	if (button == 0 || button == 2) {
		gtk_widget_destroy(GTK_WIDGET(dlg));
	}
	

	
}

void menu1 (GtkMenuItem *menuitem,gpointer user_data) {
	menustatus=GTK_PROGRESS_LEFT_TO_RIGHT;
}

void menu2 (GtkMenuItem *menuitem,gpointer user_data) {
	menustatus=GTK_PROGRESS_RIGHT_TO_LEFT;
}

void menu3 (GtkMenuItem *menuitem,gpointer user_data) {
        menustatus=GTK_PROGRESS_BOTTOM_TO_TOP;
}

void menu4 (GtkMenuItem *menuitem,gpointer user_data) {
        menustatus=GTK_PROGRESS_TOP_TO_BOTTOM;
}

==> pmudmon-0.3.tar.gz: pmudmon-0.3/properties.c <==
/* pmudmon applet
 ** Copyright (C) 2000 Mike Palczewski mpalczew@u.washington.edu
 ** 
 ** This program is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License
 ** as published by the Free Software Foundation; either version 2
 ** of the License, or (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 ** 
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 ** 02111-1307, USA.
 **/
#include "main.h"
#include "properties.h"
#include "conf.h"

GtkWidget* width;
GtkWidget* height;
GtkWidget* interval;
GtkWidget *entry1;
GtkWidget *entry2;
GtkWidget *entry3;

GtkProgressBarOrientation menustatus=0;


void menu1 (GtkMenuItem *menuitem,gpointer user_data);
void menu2 (GtkMenuItem *menuitem,gpointer user_data);
void menu3 (GtkMenuItem *menuitem,gpointer user_data);
void menu4 (GtkMenuItem *menuitem,gpointer user_data);


void properties_dialog_clicked(GnomeDialog *dlg, int button, gpointer data);

void doproperties (AppletWidget* l, gpointer m){
	GtkWidget *dialog;
	GtkWidget *label;
	GtkWidget *label2;
	GtkWidget *label3;
	GtkWidget *label4;
	GtkWidget *label5;
	GtkWidget *label6;
	GtkWidget *label7;
	GtkWidget *table;
	GtkWidget *menu;
	GtkWidget *optionmenu;
	GtkWidget *menuitem;
	GtkObject *adjustment;
	GtkObject *adjustment2;
	GtkObject *adjustment3;
	conf* config;

	config=get_conf();
	menustatus=config->orientation;
	
	dialog=gnome_dialog_new("Properties",
			GNOME_STOCK_BUTTON_OK,
			GNOME_STOCK_BUTTON_APPLY,
                        GNOME_STOCK_BUTTON_CLOSE,
                        NULL);

	gtk_signal_connect(GTK_OBJECT(dialog),"clicked",
			GTK_SIGNAL_FUNC(properties_dialog_clicked),
                        NULL);
	

	adjustment=gtk_adjustment_new(config->width,10,700,1,10,10);
	adjustment2=gtk_adjustment_new(config->height,10,700,1,10,10);
	adjustment3=gtk_adjustment_new(config->time,1,1200,1,10,10);
	
	table=gtk_table_new(2,4,FALSE);
	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox),table,
	                FALSE,FALSE,0);
	
	menu=gtk_menu_new();
	menuitem=gtk_menu_item_new_with_label("Left to Right");
	gtk_widget_show(menuitem);
	gtk_menu_append(GTK_MENU(menu),menuitem);
	gtk_signal_connect(GTK_OBJECT(menuitem),"activate",GTK_SIGNAL_FUNC(menu1),NULL);
	
	menuitem=gtk_menu_item_new_with_label("Right to Left");
	gtk_widget_show(menuitem);
        gtk_menu_append(GTK_MENU(menu),menuitem);
        gtk_signal_connect(GTK_OBJECT(menuitem),"activate",GTK_SIGNAL_FUNC(menu2),NULL);
	menuitem=gtk_menu_item_new_with_label("Bottom to Top");
	gtk_widget_show(menuitem);
        gtk_menu_append(GTK_MENU(menu),menuitem);
        gtk_signal_connect(GTK_OBJECT(menuitem),"activate",GTK_SIGNAL_FUNC(menu3),NULL);
	
	menuitem=gtk_menu_item_new_with_label("Top to Bottom");
	gtk_widget_show(menuitem);
        gtk_menu_append(GTK_MENU(menu),menuitem);
        gtk_signal_connect(GTK_OBJECT(menuitem),"activate",GTK_SIGNAL_FUNC(menu4),NULL);
	
	optionmenu=gtk_option_menu_new();
	gtk_option_menu_set_menu(GTK_OPTION_MENU(optionmenu),menu);

	gtk_option_menu_set_history(GTK_OPTION_MENU(optionmenu),
			config->orientation);
	gtk_table_attach_defaults(GTK_TABLE(table),optionmenu,1,2,3,4);	


	
	width=gtk_spin_button_new(GTK_ADJUSTMENT(adjustment),1,0);
	gtk_table_attach_defaults(GTK_TABLE(table),width,1,2,0,1);
	
	height=gtk_spin_button_new(GTK_ADJUSTMENT(adjustment2),1,0);
	gtk_table_attach_defaults(GTK_TABLE(table),height,1,2,1,2);
	
	interval=gtk_spin_button_new(GTK_ADJUSTMENT(adjustment3),1,0);
	gtk_table_attach_defaults(GTK_TABLE(table),interval,1,2,2,3);
	
	entry1=gtk_entry_new();
	gtk_table_attach_defaults(GTK_TABLE(table),entry1,1,2,4,5);
	gtk_entry_set_text(GTK_ENTRY(entry1),config->format_charging);
	
	entry2=gtk_entry_new();
	gtk_table_attach_defaults(GTK_TABLE(table),entry2,1,2,5,6);
	gtk_entry_set_text(GTK_ENTRY(entry2),config->format_charged);
	
	entry3=gtk_entry_new();
	gtk_table_attach_defaults(GTK_TABLE(table),entry3,1,2,6,7);
	gtk_entry_set_text(GTK_ENTRY(entry3),config->format_battery);
	
	gtk_table_attach_defaults(GTK_TABLE(table),
			label=gtk_label_new("Applet Width"),
			0,1,0,1);
	gtk_table_attach_defaults(GTK_TABLE(table),
			label2=gtk_label_new("Applet Height"),
			0,1,1,2);
	gtk_table_attach_defaults(GTK_TABLE(table),
			label4=gtk_label_new("Interval"),
			0,1,2,3);
	gtk_table_attach_defaults(GTK_TABLE(table),
			label3=gtk_label_new("Orientation"),
			0,1,3,4);
	gtk_table_attach_defaults(GTK_TABLE(table),
			label6=gtk_label_new("Text when charging"),
			0,1,4,5);
	gtk_table_attach_defaults(GTK_TABLE(table),
			label5=gtk_label_new("Text when charged"),
			0,1,5,6);
	gtk_table_attach_defaults(GTK_TABLE(table),
			label7=gtk_label_new("Text when running on battery"),
			0,1,6,7);
	gtk_widget_show(entry3);
	gtk_widget_show(entry2);
	gtk_widget_show(entry1);
	gtk_widget_show(interval);
	gtk_widget_show(label4);
	gtk_widget_show(menu);
	gtk_widget_show(optionmenu);
	gtk_widget_show(label7);
	gtk_widget_show(label6);
	gtk_widget_show(label5);
	gtk_widget_show(label4);
	gtk_widget_show(label3);	
	gtk_widget_show(label2);
	gtk_widget_show(label);
 	gtk_widget_show(table);	
	gtk_widget_show(height);
	gtk_widget_show(width);	
	gtk_widget_show(dialog);
	free_conf(config);

}


void properties_dialog_clicked(GnomeDialog *dlg, int button, gpointer data){
	GtkRequisition req;
	conf config;
	
	if (button == 0 || button == 1) {
		gtk_widget_set_usize(progress,
			gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(width)),
			gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(height)));
		gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(progress),menustatus);
		config.width=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(width));
		config.height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(height));
		config.time=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(interval));
		config.format_charged=gtk_entry_get_text(GTK_ENTRY(entry1));
		config.format_charging=gtk_entry_get_text(GTK_ENTRY(entry2));
		config.format_battery=gtk_entry_get_text(GTK_ENTRY(entry3));
		gtk_timeout_remove(timeout);
		timeout=gtk_timeout_add(config.time*1000,pmudmain,NULL);
		config.orientation=menustatus;
		set_conf(&config);
		pmudmain(NULL);
		
	}
	if (button == 0 || button == 2) {
		gtk_widget_destroy(GTK_WIDGET(dlg));
	}
	

	
}

void menu1 (GtkMenuItem *menuitem,gpointer user_data) {
	menustatus=GTK_PROGRESS_LEFT_TO_RIGHT;
}

void menu2 (GtkMenuItem *menuitem,gpointer user_data) {
	menustatus=GTK_PROGRESS_RIGHT_TO_LEFT;
}

void menu3 (GtkMenuItem *menuitem,gpointer user_data) {
        menustatus=GTK_PROGRESS_BOTTOM_TO_TOP;
}

void menu4 (GtkMenuItem *menuitem,gpointer user_data) {
        menustatus=GTK_PROGRESS_TOP_TO_BOTTOM;
}
